==> jc-1.4.0.tar.gz: gnu/regexp/CharIndexedInputStream.h <==
// class gnu.regexp.CharIndexedInputStream

// class file dependencies
// @dep_class 547ea2dd8ac29261 gnu_regexp_CharIndexedInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedInputStream_H_
#define _JC_gnu_regexp_CharIndexedInputStream_H_

// Forward structure declarations
struct _jc_java_io_BufferedInputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedInputStream$sub_refs	_jc_gnu_regexp_CharIndexedInputStream$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs	_jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$refs	_jc_gnu_regexp_CharIndexedInputStream$refs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$nonrefs	_jc_gnu_regexp_CharIndexedInputStream$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$object	_jc_gnu_regexp_CharIndexedInputStream$object;

typedef struct _jc_gnu_regexp_CharIndexedInputStream$fields_struct	_jc_gnu_regexp_CharIndexedInputStream$fields_struct;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vmethods	_jc_gnu_regexp_CharIndexedInputStream$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vtable	_jc_gnu_regexp_CharIndexedInputStream$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vtype	_jc_gnu_regexp_CharIndexedInputStream$vtype;

// Class fields structure
struct _jc_gnu_regexp_CharIndexedInputStream$fields_struct {
	jint	BUFFER__5fINCREMENT;
	jint	UNKNOWN;
};
extern _jc_gnu_regexp_CharIndexedInputStream$fields_struct _jc_gnu_regexp_CharIndexedInputStream$class_fields;

// Constructors
extern void _jc_gnu_regexp_CharIndexedInputStream$method$_init$cce795e7dffd722d(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, struct _jc_java_io_InputStream$object *, jint);

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedInputStream$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint);
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint);
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$next$cac9d9cc1c1d98f2(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);
extern void _jc_gnu_regexp_CharIndexedInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$move$bcf9c6b955daae71;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$next$cac9d9cc1c1d98f2;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedInputStream$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint);
	jboolean	(*next$cac9d9cc1c1d98f2)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *);
};

// Vtable
struct _jc_gnu_regexp_CharIndexedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedInputStream$vmethods	gnu_regexp_CharIndexedInputStream;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedInputStream$sub_refs {
	struct _jc_java_io_BufferedInputStream$object	*br;
	_jc_char_array	*lookBehind;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedInputStream$refs {
    _jc_gnu_regexp_CharIndexedInputStream$sub_refs	gnu_regexp_CharIndexedInputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs {
	jint	index;
	jint	bufsize;
	jint	end;
	jchar	cached;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs	gnu_regexp_CharIndexedInputStream;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedInputStream$object {
	_jc_gnu_regexp_CharIndexedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedInputStream$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedInputStream$vtype _jc_gnu_regexp_CharIndexedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedInputStream$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/CharIndexedInputStream.h <==
// class gnu.regexp.CharIndexedInputStream

// class file dependencies
// @dep_class 547ea2dd8ac29261 gnu_regexp_CharIndexedInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedInputStream_H_
#define _JC_gnu_regexp_CharIndexedInputStream_H_

// Forward structure declarations
struct _jc_java_io_BufferedInputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedInputStream$sub_refs	_jc_gnu_regexp_CharIndexedInputStream$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs	_jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$refs	_jc_gnu_regexp_CharIndexedInputStream$refs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$nonrefs	_jc_gnu_regexp_CharIndexedInputStream$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedInputStream$object	_jc_gnu_regexp_CharIndexedInputStream$object;

typedef struct _jc_gnu_regexp_CharIndexedInputStream$fields_struct	_jc_gnu_regexp_CharIndexedInputStream$fields_struct;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vmethods	_jc_gnu_regexp_CharIndexedInputStream$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vtable	_jc_gnu_regexp_CharIndexedInputStream$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedInputStream$vtype	_jc_gnu_regexp_CharIndexedInputStream$vtype;

// Class fields structure
struct _jc_gnu_regexp_CharIndexedInputStream$fields_struct {
	jint	BUFFER__5fINCREMENT;
	jint	UNKNOWN;
};
extern _jc_gnu_regexp_CharIndexedInputStream$fields_struct _jc_gnu_regexp_CharIndexedInputStream$class_fields;

// Constructors
extern void _jc_gnu_regexp_CharIndexedInputStream$method$_init$cce795e7dffd722d(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, struct _jc_java_io_InputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedInputStream$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedInputStream$method$next$cac9d9cc1c1d98f2(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_CharIndexedInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$move$bcf9c6b955daae71;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$next$cac9d9cc1c1d98f2;
extern _jc_method _jc_gnu_regexp_CharIndexedInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedInputStream$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*next$cac9d9cc1c1d98f2)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_regexp_CharIndexedInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_CharIndexedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedInputStream$vmethods	gnu_regexp_CharIndexedInputStream;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedInputStream$sub_refs {
	struct _jc_java_io_BufferedInputStream$object	*br;
	_jc_char_array	*lookBehind;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedInputStream$refs {
    _jc_gnu_regexp_CharIndexedInputStream$sub_refs	gnu_regexp_CharIndexedInputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs {
	jint	index;
	jint	bufsize;
	jint	end;
	jchar	cached;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedInputStream$sub_nonrefs	gnu_regexp_CharIndexedInputStream;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedInputStream$object {
	_jc_gnu_regexp_CharIndexedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedInputStream$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedInputStream$vtype _jc_gnu_regexp_CharIndexedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedInputStream$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedInputStream_H_ */
